**To update the ``enabled`` state for a device**

The following ``update-device-state`` sets the state of the specified device to ``enabled``. ::

    aws iot1click-devices update-device-state \
        --device-id G030PM0123456789 \
        --enabled

This command produces no output.

For more information, see `Using AWS IoT 1-Click with the AWS CLI <https://docs.aws.amazon.com/iot-1-click/latest/developerguide/1click-cli.html>`__ in the *AWS IoT 1-Click Developer Guide*.
